"""
Файл для констант приложения.
"""
import os


class ConstConfig:
    """
    Класс с конфигурационными константами.
    """

    DEFAULT_LISTEN_IP = '0.0.0.0'
    DEFAULT_LISTEN_PORT = 31000
    USE_HTTPS = False
    # константы для utils.base
    INTRANET_IP = "10.255.255.255"
    LOCAL_IP = "127.0.0.1"

    DEFAULT_TIME_TO_RUN = 6
    DEFAULT_RETRY_DELAY = 3
    DEFAULT_RETRIES_COUNT = 3

    SESSION_AGENT_CONFIG = {
        "AGENT": {
            "LISTEN_IP": DEFAULT_LISTEN_IP,
            "LISTEN_PORT": DEFAULT_LISTEN_PORT,
        },
        "SSL": {
            "USE_HTTPS": USE_HTTPS,
        },
        "LOGGING": {
            # Допустимые значения: NOTSET, DEBUG, INFO, WARNING, ERROR, CRITICAL
            "LEVEL": "INFO",
            "ROTATION_LIMIT": 5,
            "MAX_FILE_SIZE": 2 * 1024 * 1024,
        }
    }
    # SessionAgentService
    SSA_TIME_TO_RUN = os.getenv("SSA_TIME_TO_RUN", DEFAULT_TIME_TO_RUN)
    SSA_RETRY_DELAY = os.getenv("SSA_RETRY_DELAY", DEFAULT_RETRY_DELAY)
    SSA_RETRIES_COUNT = os.getenv("SSA_RETRIES_COUNT", DEFAULT_RETRIES_COUNT)
    # utils.secure
    ACCESS_TOKEN_TTL = 2 * 60 * 60
    REFRESH_TOKEN_TTL = 24 * 60 * 60
    ACCESS_TOKEN_TITLE = 'Access'
    REFRESH_TOKEN_TITLE = 'Refresh'
    CACHE_LIMIT = 2048**2  # The issue limit is ~25,000 tokens per hour.


class ConstMiddleware:
    """Константы для core.middleware"""
    SECURE_FIELDS = ("password",)
    SECURE_VALUE_MASK = "*" * 3


class ConstEnvironment:
    """Общие константы для запуска окружения."""

    OVIRT_VM = 'oVirt'
    VIRTUAL_BOX_VM = ['VirtualBox', 'innotek GmbH']
    HYPER_V_VM = 'Virtual Machine'
    SSA_URL_DELEGATE_NAME = "SSA_URL_DELEGATE", # .env_config
    
    SUPPORTED_VMS = [
        OVIRT_VM,
        *VIRTUAL_BOX_VM,
        HYPER_V_VM]
    # SESSION_STATES в environment.checks нигде неиспользуется
    SESSION_STATES = {"Активно": "A", "Диск": "I", "Active": "A", "Inactive": "I"}
    # .env_config
    SSA_URL_DELEGATE = os.getenv(
        f"{SSA_URL_DELEGATE_NAME}", "http://127.0.0.1:31000/agent/delegate"
    )
    # Windows checks cmd:
    # Check windows hardware serial number via CMD
    HARDWARE_SERIAL_NUMBER = 'WMIC BIOS GET SERIALNUMBER'
    # Check windows hardware model via CMD
    HARDWARE_MODEL = 'WMIC COMPUTERSYSTEM GET MODEL'
    # Check windows hardware manufacturer number via CMD
    HARDWARE_MANUFACTURER = 'WMIC COMPUTERSYSTEM GET MANUFACTURER'
    
    # Linux checks:
    # Checking if os is virtual machine via bash command: systemd-detect-virt
    LINUX_DETECT_VIRT = 'systemd-detect-virt'
    # Checking if os is virtual machine via bash command: hostnamectl
    LINUX_HOSTNAMECTL = 'hostnamectl|grep -i Virtualization'
    # Checking if os is virtual machine via bash command: dmesg
    LINUX_DMESG = 'dmesg|grep -i hypervisor'
    # Result of the check if operating system is not VM
    LINUX_DETECT_VIRT_IS_PC = 'none'
    # Operating systems
    WINDOWS = 'Windows'
    LINUX = 'Linux'


class ConstHandlersBase:
    """Базовый класс констант роуты и ответы для хэндлеров."""

    PATH_PUBLIC_STATUS = '/public/status'
    TEST = '/test'
    TESTCONNECT = '/testconnect'
    SESSION = '/session'
    LOGIN = '/login'
    DISCONNECT = '/ disconnect'
    VERSION = '/version'
    SESSION_REQUEST = '/sessionrequest'
    PROGRAM_REQUEST = '/programrequest'
    INSTALL_RDS_ROLE = '/install_rds_role'

    PATH_DELEGATE = "/agent/delegate"
    RESPONSE_OK = {"status": "ok"}


class ConstServicesBase:
    """Общие константы для для сервисов."""

    SESSION_STATES = "IA" # общаяя для services.meta.stal|services.meta.rds|utils.rds|services.stal
    RESPONSE_SUCCESS = {"result": "success"}  # в services.meta.rds она же в def install_rds_role(self)
    REQUEST_TIMEOUT = 3  # константа из services.agent


class ConstBaseRds(ConstServicesBase):
    """Константы для сервиса RDS."""

    # Local server handler
    WTS_CURRENT_SERVER_HANDLE = 0
    # List with proc names for checking rds instance
    RDS_PROC_NAMES = ["tssdis.exe"]
    # Remote application process alias
    REMOTE_APP_PROC_NAME = "rdpinit.exe"
    # Message if platform not Windows
    NOT_WIN_MESSAGE = "Platform is not Windows!"

    STATE_INVALID = 'STATE_INVALID'
    STATE_ACTIVE = 'STATE_ACTIVE'
    STATE_CONNECTED = 'STATE_CONNECTED'
    STATE_CONNECTQUERY = 'STATE_CONNECTQUERY'
    STATE_SHADOW = 'STATE_SHADOW'
    STATE_DISCONNECTED = 'STATE_DISCONNECTED'
    STATE_IDLE = 'STATE_IDLE'
    STATE_LISTEN = 'STATE_LISTEN'
    STATE_RESET = 'STATE_RESET'
    STATE_DOWN = 'STATE_DOWN'
    STATE_INIT = 'STATE_INIT'

    SESSION_ID_STATES = {
        -1: STATE_INVALID,
        0: STATE_ACTIVE,
        1: STATE_CONNECTED,
        2: STATE_CONNECTQUERY,
        3: STATE_SHADOW,
        4: STATE_DISCONNECTED,
        5: STATE_IDLE,
        6: STATE_LISTEN,
        7: STATE_RESET,
        8: STATE_DOWN,
        9: STATE_INIT,
    }
    SUCCESS = "success"  # встречается в services.meta.rds


class ConstBaseStal(ConstServicesBase):
    """Константы для сервиса STAL."""
    
    # глубина цвета
    DEPTH = 24
    # Разрешение экрана
    DISPLAY_WIDTH = 1024
    DISPLAY_HEIGHT = 768


class ExceptionMessages:
    """Сообщения для исключений."""

    NOT_INTENDED_OS = 'The method is not intended to be called on this OS.'
    STAL_SESSION_NOT_CREATED ='STAL session not created!'