'''
Файл констант работающих из окружения linux
'''
import os
from pathlib import Path

from constants.common_const import (
    ConstEnvironment,
    ConstHandlersBase,
    ConstBaseStal,
    ConstConfig
)


class ConstMeta(ConstHandlersBase):
    """Класс с роутами для хэндлеров метапоставщика."""

    PATH_PREFIX = '/meta'

    LOGOUT = '/logout'
    PUBLISHED_APPS = '/published_apps'
    AVAILIABLE_APPS = '/available_apps'


class ConstLinuxEnv(ConstEnvironment, ConstConfig):
    """Константы для окружения linux."""

    BASE_PATH = "/etc/opt/termidesk-ssa"
    # .env_config
    ENV_FILE_PATH = os.path.join(BASE_PATH , "config/.env")
    # .default
    CONFIG_FILE_PATH = os.path.join(
        BASE_PATH, "session_agent.ini"
    )
    LOG_FILE_PATH = "/var/log/termidesk/session-agent.log"
    SESSION_AGENT_CONFIG = {
        "AGENT": {
            "LISTEN_IP": ConstConfig.DEFAULT_LISTEN_IP,
            "LISTEN_PORT": ConstConfig.DEFAULT_LISTEN_PORT,
        },
        "SSL": {
            "USE_HTTPS": ConstConfig.USE_HTTPS,
            "CERTIFICATE_PATH": os.path.join(
                BASE_PATH, "certs", "cert.pem"
            ),
            "PRIVATE_KEY_PATH": os.path.join(
                BASE_PATH, "certs", "key.pem"
            ),
        },
        "LOGGING": {
            # Допустимые значения: NOTSET, DEBUG, INFO, WARNING, ERROR, CRITICAL
            "LEVEL": "INFO",
            "ROTATION_LIMIT": 5,
            "MAX_FILE_SIZE": 2 * 1024 * 1024,
        }
    }


class ConstStal(ConstHandlersBase, ConstBaseStal, ConstLinuxEnv):
    """Класс с роутами для STAL."""

    PATH_PREFIX = '/stal'

    SHUTDOWN = '/shutdown'

    PATH_TEST = PATH_PREFIX + ConstHandlersBase.TEST
    PATH_SESSION = PATH_PREFIX + ConstHandlersBase.SESSION
    PATH_LOGIN = PATH_PREFIX + ConstHandlersBase.LOGIN
    PATH_TESTCONNECT = PATH_PREFIX + ConstHandlersBase.TESTCONNECT
    PATH_DISCONNECT = PATH_PREFIX + ConstHandlersBase.DISCONNECT
    PATH_VERSION = PATH_PREFIX + ConstHandlersBase.VERSION
    PATH_SHUTDOWN = PATH_PREFIX + SHUTDOWN
    PATH_SESSION_REQUEST = PATH_PREFIX + ConstHandlersBase.SESSION_REQUEST
    PATH_PROGRAM_REQUEST = PATH_PREFIX + ConstHandlersBase.PROGRAM_REQUEST
