"""
Файл констант работающих из окружения windows.
"""
import os
import winreg as wrg

from constants.common_const import (
    ConstBaseRds,
    ConstConfig,
    ConstEnvironment,
    ConstHandlersBase
)

class ConstWinCmd:
    """Константы с коммандами для windows."""

    GET_REMOTE_APP_USERS_CMD = (
        'Get-RDRemoteApp -CollectionName "{}" -Alias "{}" | Format-List UserGroups'
    )  # комманда из services.rds и services.meta.rds
    LOGOFF_USER_CMD = 'cmd/c "echo y|LOGOFF /VM {}"'
    # комманды из utils.meta.rds: """Configuring the Windows firewall"""
    # там комманды в f-strings эти под str.format()
    RDS_CMD = 'netsh advfirewall firewall set rule group="{}" new enable=yes'
    SSA_CMD = (
        "New-NetFirewallRule -DisplayName AllowSSA -Direction Inbound -Protocol TCP "
        "-LocalPort {} -Action Allow"
    )


class ConstWindowsEnv(ConstEnvironment, ConstWinCmd, ConstConfig):
    """Константы для окружения windows."""

    PROGRAM_DATA = os.path.expandvars(r"%PROGRAMDATA%")
    BASE_PATH = os.path.join(
        PROGRAM_DATA, "UVEON", "Termidesk Session Agent"
    )
    # .env_config
    ENV_FILE_PATH = os.path.join(
        BASE_PATH, "config", ".env"
    )
    # .default
    CONFIG_FILE_PATH = os.path.join(
        BASE_PATH, "session_agent.ini"
    )
    LOG_FILE_PATH = os.path.join(
        BASE_PATH, "log", "session-agent.log"
    )
    SESSION_AGENT_CONFIG = {
        "AGENT": {
            "LISTEN_IP": ConstConfig.DEFAULT_LISTEN_IP,
            "LISTEN_PORT": ConstConfig.DEFAULT_LISTEN_PORT,
        },
        "SSL": {
            "USE_HTTPS": ConstConfig.USE_HTTPS,
            "CERTIFICATE_PATH": os.path.join(
                BASE_PATH, "certs", "cert.pem"
            ),
            "PRIVATE_KEY_PATH": os.path.join(
                BASE_PATH, "certs", "key.pem"
            ),
        },
        "LOGGING": {
            # Допустимые значения: NOTSET, DEBUG, INFO, WARNING, ERROR, CRITICAL
            "LEVEL": "INFO",
            "ROTATION_LIMIT": 5,
            "MAX_FILE_SIZE": 2 * 1024 * 1024,
        }
    }


class ConstHandlerRds(ConstHandlersBase):
    """Класс с роутами для хэндлеров."""

    PATH_PREFIX = '/rds'

    APPS = '/apps'
    COLLECTIONS = '/collections'
    USERS = '/users'
    COLLECTION_INFO = '/collection_info'

    PATH_TEST = PATH_PREFIX + ConstHandlersBase.TEST
    PATH_TESTCONNECT = PATH_PREFIX + ConstHandlersBase.TESTCONNECT
    PATH_SESSION = PATH_PREFIX + ConstHandlersBase.SESSION
    PATH_LOGIN = PATH_PREFIX + ConstHandlersBase.LOGIN
    PATH_DISCONNECT = PATH_PREFIX + ConstHandlersBase.DISCONNECT
    PATH_APPS = PATH_PREFIX + APPS
    PATH_COLLECTIONS = PATH_PREFIX + COLLECTIONS
    PATH_APPS_USERS = PATH_APPS + USERS
    PATH_COLLECTION_INFO = PATH_PREFIX + COLLECTION_INFO
    PATH_INSTALL_RDS_ROLE = PATH_PREFIX + ConstHandlersBase.INSTALL_RDS_ROLE


class ConstRds(ConstBaseRds, ConstHandlerRds, ConstWindowsEnv):
    """Константы для сервиса RDS."""

    RESERVED = 0
    # Registry value is disabled
    REG_DISABLED = 0
    # Registry value is enabled
    REG_ENABLED = 1
    # реестр локальной машины
    REG_LOCATION = wrg.HKEY_LOCAL_MACHINE
    # путь в реестре до списка приложений
    APP_REG_PATH = (
        "SOFTWARE\\Microsoft\\Windows NT\\CurrentVersion\\Terminal Server\\TSAppAllowList\\Applications"
    )
    # Machine language
    MACHINE_LANG = dict(
        RU="дистанционное управление рабочим столом",
        EN="remote desktop",
    )
    # Winreg params
    REG_DWORD_VALUES = dict(
        Enable=0x00000001,
        Disable=0x00000000,
    )
