﻿# Fixme: these imports are made this way to make pyinstaller work.
#  Need to find another way for import migration in pyinstaller.
import dependency_injector.containers as containers
import dependency_injector.providers as providers
from environment.checks import PlatformEnvironment
from services.agent import AgentService
from utils.secure import JWTAuthorization


class Container(containers.DeclarativeContainer):
    # Agent TODO: If possible, add logger and params.url in depends & Add in handlers
    # wiring_config = containers.WiringConfiguration(modules=["handlers.base"])
    #
    # agent_service = providers.Factory(AgentService)

    # STAL
    if PlatformEnvironment.is_linux():
        from services.stal import StalService
        from services.meta.stal import MetaService
        from constants.linux.constants import ConstStal

        # Config for modules
        wiring_config = containers.WiringConfiguration(modules=[
            "handlers.stal",
            "handlers.meta",
            "handlers.auth",
            "handlers.base",
            "core.secure",
        ])


        # Auth
        jwt_auth = providers.Singleton(JWTAuthorization)
        
        # constants
        service_constants = providers.Singleton(ConstStal)
        
        # Services
        service = providers.Singleton(StalService, const=service_constants)
        # Services, META
        meta_service = providers.Singleton(MetaService, const=service_constants)

    # RDS
    elif PlatformEnvironment.is_windows():
        from services.rds import RdsService
        from utils.rds import WMIHandler
        from utils.meta.rds import ApplicationRegEdit
        from services.meta.rds import MetaService
        from constants.windows.constants import ConstRds

        # Config for modules
        wiring_config = containers.WiringConfiguration(modules=[
            "handlers.rds",
            "handlers.meta",
            "handlers.auth",
            "services.rds",
            "utils.rds",
            "core.secure",
        ])

        # Auth
        jwt_auth = providers.Singleton(JWTAuthorization)

        # Utils, META
        # TODO: If possible, add a link to the ApplicationRegEdit.
        #  Need implementation with passing input `name` data to container
        # application_reg_edit = providers.Factory(
        #     ApplicationRegEdit,
        #     params=MetaPublishAppModel,
        #     name=""
        # )

        # constants
        service_constants = providers.Singleton(ConstRds)
        # Utils
        wmi_handler = providers.Factory(WMIHandler)
        # Services
        service = providers.Singleton(
            RdsService,
            wmi_handler=wmi_handler,
            const=service_constants
        )
        # Services, META.rds
        meta_service = providers.Singleton(
            MetaService,
            const=service_constants
            # application_reg_edit=application_reg_edit,
        )
