import os
import logging

from dotenv import load_dotenv
from environment.checks import PlatformEnvironment

logger = logging.getLogger(__name__)

SSA_URL_DELEGATE_NAME = "SSA_URL_DELEGATE"
SSA_URL_DELEGATE = os.getenv(f"{SSA_URL_DELEGATE_NAME}", "http://127.0.0.1:31000/agent/delegate")

if PlatformEnvironment.is_linux():
    ENV_FILE_PATH = "/etc/opt/termidesk-ssa/config/.env"

if PlatformEnvironment.is_windows():
    PROGRAM_DATA = os.path.expandvars(r"%PROGRAMDATA%")
    ENV_FILE_PATH = os.path.join(
        PROGRAM_DATA, "UVEON", "Termidesk Session Agent", "config", ".env"
    )

env_exist = load_dotenv(ENV_FILE_PATH)  # Take environment variables from .env. Return True if .env file is exist

if not env_exist:
    os.makedirs(os.path.dirname(ENV_FILE_PATH), exist_ok=True)
    with open(ENV_FILE_PATH, "w+") as f:
        f.write(f"{SSA_URL_DELEGATE_NAME}={SSA_URL_DELEGATE}\n")
        logger.info(f"Initial .env file on path {ENV_FILE_PATH}")
