import os
import platform
import subprocess

from constants.common_const import ConstEnvironment as env_const


class PlatformEnvironment:
    """Environment checks of the current operating system"""
    def __init__(self):
        self.system = platform.uname().system

    def _check_windows_platform(self, command: str) -> bool:
        """Checking if any vm from VM_LIST in output of command. Windows only."""
        try:
            result = os.popen(command).read()
            is_vm = any(vm in result for vm in env_const.SUPPORTED_VMS)
        # Todo (ap): пустой except. Необходимо конкретизировать ошибку. После чего удалить "# noqa E722"
        except:  # noqa E722
            is_vm = False
        return is_vm

    def _check_windows_serial(self) -> bool:
        """Checking if serial number from output of the command == 0:str. Windows only."""
        try:
            result = os.popen(env_const.HARDWARE_SERIAL_NUMBER).read().replace('\n', '').split()
            is_vm = True if result[1] == '0' else False
        # Todo (ap): пустой except. Необходимо конкретизировать ошибку. После чего удалить "# noqa E722"
        except:  # noqa E722
            is_vm = False
        return is_vm

    def _check_linux_platform(self, command: str) -> bool:
        """Checking if Linux system is VM from output of the bash command"""
        try:
            result = os.popen(command).read().rstrip().split(': ')[-1]
            is_vm = True if result else False
        # Todo (ap): пустой except. Необходимо конкретизировать ошибку. После чего удалить "# noqa E722"
        except:  # noqa E722
            is_vm = False
        return is_vm

    def _detect_linux_virt(self) -> bool:
        """Checking if Linux system is VM from output of the bash command"""
        try:
            result = subprocess.run(
                env_const.LINUX_DETECT_VIRT,
                stdout=subprocess.PIPE
            ).stdout.decode().rstrip()
            is_vm = True if result != env_const.LINUX_DETECT_VIRT_IS_PC else False
        # Todo (ap): пустой except. Необходимо конкретизировать ошибку. После чего удалить "# noqa E722"
        except:  # noqa E722
            is_vm = False
        return is_vm

    def _windows_is_vm(self) -> bool:
        """Checking if Windows system is Virtual Machine"""
        is_vm = any([
            self._check_windows_serial(),
            self._check_windows_platform(env_const.HARDWARE_MANUFACTURER),
            self._check_windows_platform(env_const.HARDWARE_MODEL)
        ])
        return is_vm

    def _linux_is_vm(self) -> bool:
        """Checking if Linux system is Virtual Machine"""
        is_vm = any([
            self._detect_linux_virt(),
            self._check_linux_platform(env_const.LINUX_HOSTNAMECTL),
            self._check_linux_platform(env_const.LINUX_DMESG)
        ])
        return is_vm

    def is_vm(self) -> bool:
        """Checking if supported system is a virtual machine.
        If system is not supported raise OSError.
        """
        try:
            is_vm = eval('self._{}_is_vm()'.format(self.system.lower()))
            return is_vm

        except AttributeError:
            raise OSError('Current operating system is not supported: {}.'.format(self.system))

    def is_pc(self) -> bool:
        """Checking if the system is a physical machine.
        If system is not supported raise OSError.
        """
        return not self.is_vm()

    @staticmethod
    def is_windows() -> bool:
        """Checking if the platform is a Windows."""
        return platform.uname().system == env_const.WINDOWS

    @staticmethod
    def is_linux() -> bool:
        """Checking if the platform is a Linux."""
        return platform.uname().system == env_const.LINUX
