"""
This module provides functions for recording events in the OS system log.

How to use:

eventlog.write_event("Transmits a message to the system log.", "Message type")

Example usage:

>>> eventlog.write_event("The Sessional Agent starts up.", "INFO")
"""

from environment.checks import PlatformEnvironment


def write_event(event_strings: str, event_type: str) -> None:
    if PlatformEnvironment.is_linux():
        import syslog

        event_type_linux = {
            "INFO": syslog.LOG_INFO,
            "WARNING": syslog.LOG_WARNING,
            "ERROR": syslog.LOG_ERR,
            "DEBUG": syslog.LOG_DEBUG
        }

        syslog.openlog(ident='SSA', logoption=syslog.LOG_PID, facility=syslog.LOG_LOCAL0)
        # label = next(key for key, value in event_type_linux.items() if value == event_type_linux[event_type])
        syslog.syslog(event_type_linux[event_type], event_strings)
        syslog.closelog()

    elif PlatformEnvironment.is_windows():
        import win32evtlogutil
        import win32evtlog

        # LOG_NAME = "Application"
        evt_app_name = "SSA"
        # MESSAGE_FILE = r"path\to\ssa.dll"
        evt_id = 10000
        # EVT_CATEG = 1234
        event_type_win = {
            "INFO": win32evtlog.EVENTLOG_INFORMATION_TYPE,
            "WARNING": win32evtlog.EVENTLOG_WARNING_TYPE,
            "ERROR": win32evtlog.EVENTLOG_ERROR_TYPE,
            "DEBUG": win32evtlog.EVENTLOG_INFORMATION_TYPE
        }
        event_data = bytes(event_strings, 'utf-8')
        event_strings = [event_strings]
        event_type = event_type_win[event_type]

        win32evtlogutil.ReportEvent(
            evt_app_name, evt_id, eventType=event_type, strings=event_strings,
            data=event_data)


