import os
from typing import Dict, List, Optional

from fastapi_utils.api_model import APIModel

from pydantic import BaseModel, validator


# Input Models
class MetaUserModel(APIModel):
    login: str
    domain: str = ""
    password: str


class MetaLogoutModel(APIModel):
    session_id: int


class MetaPublishAppModel(APIModel):
    name: str
    path: str

    @validator("name")
    def check_name_not_empty(cls, v):
        if v == "":
            raise ValueError("Name is empty!")
        return v

    @validator("path")
    def check_file_not_exists(cls, v):
        if not os.path.exists(v):
            raise ValueError("File does not exist.")
        return v


class MetaProgramRequestModel(MetaUserModel):
    program: str


# Output Model
class MetaSession(BaseModel):
    username: str
    session_id: int
    host_server: str
    state: str
    is_desktop: bool


class MetaSessions(BaseModel):
    sessions: Optional[List[MetaSession]]


class MetaTest(BaseModel):
    service_name: str = "rds"


class MetaTestConnect(BaseModel):
    is_connected: Optional[bool]


class MetaApps(BaseModel):
    apps: Optional[List[str]]


class MetaLogout(BaseModel):
    disconnect_done: Optional[bool]


class MetaLogin(BaseModel):
    auth_done: Optional[bool]


class MetaPublishApp(BaseModel):
    is_created: Optional[bool]


class MetaDeleteApp(BaseModel):
    is_deleted: Optional[bool]


class MetaAvailableApps(BaseModel):
    available_apps: Optional[Dict[str, str]] = {
        "app1": "C:\\example1.exe",
        "app2": "C:\\example2.exe",
    }


class MetaSessionRequest(BaseModel):
    session_id: Optional[int]


class MetaInstallRdsRole(BaseModel):
    result: str
