from typing import Union, List

from fastapi_utils.api_model import APIModel
from pydantic import BaseModel


class RdsUserModel(APIModel):
    login: str
    domain: Union[str, None] = ''
    password: str


class RdsLogoutModel(APIModel):
    session_id: int


class RdsRemoteAppModel(APIModel):
    collection: str


class RemoteAppUsersModel(APIModel):
    collection: str
    app_alias: str


class CheckInstanceResponse(BaseModel):
    is_rds: bool


class Session(BaseModel):
    username: str
    session_id: int
    host_server: str
    state: str
    is_desktop: bool


class SessionsResponse(BaseModel):
    sessions: Union[List[Session], None]


class LoginResponse(BaseModel):
    auth_done: bool


class LogoutUserResponse(BaseModel):
    disconnect_done: bool


class TestConnectResponse(BaseModel):
    is_connected: bool


class Collection(BaseModel):
    name: str
    is_desktop: bool


class CollectionsResponse(BaseModel):
    collections: Union[List[Collection], None]


class RemoteApp(BaseModel):
    Alias: str
    DisplayName: str


class RdsRemoteAppResponse(BaseModel):
    apps: Union[List[RemoteApp], None]


class RemoteAppUsersResponse(BaseModel):
    app_users: Union[List[str], None]


class CollectionInfo(BaseModel):
    gateway_name: Union[str, None]


class CollectionInfoResponse(BaseModel):
    collection_info: Union[CollectionInfo, None]
