import logging

from OpenSSL import crypto


logger = logging.getLogger("ssl")


def generate_selfsigned_cert(
        key_file=None,
        cert_file=None,
        email_address="cert@uveon.ru",
        common_name="127.0.0.1",
        country_name="RU",
        locality_name="Moscow",
        state_or_province_name="Moscow",
        organization_name="UVEON",
        organization_unit_name="ITG",
        serial_number=0,
        validity_end_in_seconds=10 * 365 * 24 * 60 * 60,
        create_files=True
):
    k = crypto.PKey()
    k.generate_key(crypto.TYPE_RSA, 2048)
    cert = crypto.X509()
    cert.get_subject().C = country_name
    cert.get_subject().ST = state_or_province_name
    cert.get_subject().L = locality_name
    cert.get_subject().O = organization_name  # noqa
    cert.get_subject().OU = organization_unit_name
    cert.get_subject().CN = common_name
    cert.get_subject().emailAddress = email_address
    cert.set_serial_number(serial_number)
    cert.gmtime_adj_notBefore(0)
    cert.gmtime_adj_notAfter(validity_end_in_seconds)
    cert.set_issuer(cert.get_subject())
    cert.set_pubkey(k)
    cert.sign(k, "sha512")

    key_data = crypto.dump_privatekey(crypto.FILETYPE_PEM, k).decode("utf-8")
    cert_data = crypto.dump_certificate(crypto.FILETYPE_PEM, cert).decode("utf-8")

    if create_files:
        logger.info("Пара SSL сертификат — приватный ключ не были найдены.")
        with open(cert_file, "wt") as f:
            f.write(cert_data)
            logger.info(f"Сгенерирован самоподписанный сертификат: {cert_file}")
        with open(key_file, "wt") as f:
            f.write(key_data)
            logger.info(f"Сгенерирован приватный ключ: {key_file}")

    return key_data, cert_data
