import logging
import requests
from fastapi import status

from constants.common_const import ConstServicesBase as const

logger = logging.getLogger(__name__)


class AgentService:
    """class for interacting with the VM Agent"""
    def __init__(self, vm_delegate_url):
        self.vm_delegate_url = vm_delegate_url
        logger.info(f"{__class__.__name__}: SSA accept "
                    "delegation and management from VM Agent")

    def process(self):
        """Method for initiating settings
        from the SSA side after receiving the delegate signal from an VM Agent"""

        # Calling the target function of execute SSA settings
        self.setup_agent()

        # After completing the setup, we return control to the VM agent
        self.delegate_control()

    def setup_agent(self):
        """A method for execute settings from the SSA side
        after receiving the delegate signal from the agent"""
        pass

    def delegate_control(self):
        """delegate control back to agent
        after completion all actions in process"""

        log_postfix = f"request: {const.RESPONSE_SUCCESS} " \
                      f"vm_delegate_url: {self.vm_delegate_url}"
        try:
            request = requests.post(self.vm_delegate_url,
                                    json=const.RESPONSE_SUCCESS,
                                    timeout=const.REQUEST_TIMEOUT)
            if request.status_code == status.HTTP_200_OK:
                logger.info(f"{__class__.__name__}: VM agent accepted "
                            "delegation and management from SSA. "
                            f"{log_postfix}")
                return True
            else:
                logger.error(f"{__class__.__name__}: VM agent don't accept "
                             "delegation and management from SSA. "
                             f"Status_code: {request.status_code} "
                             f"{log_postfix}")
                return False
        except requests.ConnectionError:
            logger.error(f"{__class__.__name__}: "
                         f"VM agent don't accept delegation "
                         f"and management from SSA. "
                         f"{log_postfix}", exc_info=True)
            return False
